@@ -7,7 +7,7 @@ SEXP Vcut(SEXP Vmat, SEXP lamfun, SEXP nunits, SEXP ngrid, SEXP Agrid) {
   /* lam_fun - vector of length ngrid */
   SEXP ans;
   int nrow, ncol, ii, jj;
-  double tst, g0, gdelt, slop;
+  double g0, gdelt, slop;
   
   nrow = INTEGER(nunits)[0];
   ncol = INTEGER(ngrid)[0];
@@ -16,13 +16,12 @@ SEXP Vcut(SEXP Vmat, SEXP lamfun, SEXP nunits, SEXP ngrid, SEXP Agrid) {
   
   for (ii=0; ii < nrow; ii++) {
      for(jj=0; jj < ncol; jj++)  {
-         tst = REAL(Vmat)[ii + nrow*jj] - REAL(lamfun)[jj];
+         // tst = REAL(Vmat)[ii + nrow*jj] - REAL(lamfun)[jj];
          // maybe change the tst>= 0 condition or
          // compare(Vmat) with (lamfun) directly
          // Interpolation:
          
-         if(tst >= 0) {
-            //tstp1 = REAL(Vmat)[ii + nrow*jj - 1] - REAL(lamfun)[jj - 1];
+         if(REAL(Vmat)[ii + nrow*jj] > REAL(lamfun)[jj]) {
             // check if "jj=0"
             if(jj > 0) {
                 g0 = REAL(Vmat)[ii + nrow*jj - 1] - REAL(lamfun)[jj - 1]; 
